<?php

namespace Database\ActivityProject\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Database\ActivityProject\Http\Requests\AcitivityProjectAdminRequest;
use Database\ActivityProject\Interfaces\AcitivityProjectRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class AcitivityProjectAdminController extends AdminController
{
    /**
     * Initialize acitivity_project controller.
     *
     * @param type AcitivityProjectRepositoryInterface $acitivity_project
     *
     * @return type
     */
    public function __construct(AcitivityProjectRepositoryInterface $acitivity_project)
    {
        $this->model = $acitivity_project;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(AcitivityProjectAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('activity_project.acitivity_project.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('activity_project::acitivity_project.names').' :: ');

        return $this->theme->of('activity_project::admin.acitivity_project.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(AcitivityProjectAdminRequest $request, $id)
    {
        $acitivity_project = $this->model->find($id);

        if (empty($acitivity_project)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('activity_project::admin.acitivity_project.new');
        }

        if ($request->wantsJson()) {
            return $acitivity_project;
        }

        Former::populate($acitivity_project);

        return view('activity_project::admin.acitivity_project.show', compact('acitivity_project'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(AcitivityProjectAdminRequest $request)
    {
        $acitivity_project = $this->model->findOrNew(0);
        Former::populate($acitivity_project);

        return view('activity_project::admin.acitivity_project.create', compact('acitivity_project'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AcitivityProjectAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $acitivity_project = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('activity_project::acitivity_project.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(AcitivityProjectAdminRequest $request, $id)
    {
        $acitivity_project = $this->model->find($id);

        Former::populate($acitivity_project);

        return view('activity_project::admin.acitivity_project.edit', compact('acitivity_project'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(AcitivityProjectAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $acitivity_project = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('activity_project::acitivity_project.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(AcitivityProjectAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('activity_project::acitivity_project.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
