<?php

namespace Database\ActivityProject\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Database\ActivityProject\Http\Requests\AcitivityProjectUserRequest;
use Database\ActivityProject\Interfaces\AcitivityProjectRepositoryInterface;
use Response;
use User;

class AcitivityProjectUserController extends UserController
{
    /**
     * Initialize acitivity_project controller.
     *
     * @param type AcitivityProjectRepositoryInterface $acitivity_project
     *
     * @return type
     */
    public function __construct(AcitivityProjectRepositoryInterface $acitivity_project)
    {
        $this->model = $acitivity_project;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(AcitivityProjectUserRequest $request)
    {
        $acitivity_projects = $this->model->all();

        $this->theme->prependTitle(trans('activity_project::acitivity_project.names').' :: ');

        return $this->theme->of('activity_project::user.acitivity_project.index', compact('acitivity_projects'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(AcitivityProjectUserRequest $request, $role, $id)
    {
        $acitivity_project = $this->model->find($id);

        return $this->theme->of('activity_project::user.acitivity_project.show', compact('acitivity_project'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(AcitivityProjectUserRequest $request)
    {
        $acitivity_project = $this->model->findOrNew(0);

        Former::populate($acitivity_project);

        return $this->theme->of('activity_project::user.acitivity_project.create', compact('acitivity_project'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AcitivityProjectUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $acitivity_project = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('activity_project::acitivity_project.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(AcitivityProjectUserRequest $request, $role, $id)
    {
        $acitivity_project = $this->model->find($id);

        Former::populate($acitivity_project);

        return $this->theme->of('activity_project::user.acitivity_project.edit', compact('acitivity_project'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(AcitivityProjectUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $acitivity_project = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('activity_project::acitivity_project.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(AcitivityProjectUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('activity_project::acitivity_project.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
