<?php

namespace Database\ActivityProject\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Database\ActivityProject\Http\Requests\TaskAdminRequest;
use Database\ActivityProject\Interfaces\TaskRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class TaskAdminController extends AdminController
{
    /**
     * Initialize task controller.
     *
     * @param type TaskRepositoryInterface $task
     *
     * @return type
     */
    public function __construct(TaskRepositoryInterface $task)
    {
        $this->model = $task;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(TaskAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('activity_project.task.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('activity_project::task.names').' :: ');

        return $this->theme->of('activity_project::admin.task.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(TaskAdminRequest $request, $id)
    {
        $task = $this->model->find($id);

        if (empty($task)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('activity_project::admin.task.new');
        }

        if ($request->wantsJson()) {
            return $task;
        }

        Former::populate($task);

        return view('activity_project::admin.task.show', compact('task'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TaskAdminRequest $request)
    {
        $task = $this->model->findOrNew(0);
        Former::populate($task);

        return view('activity_project::admin.task.create', compact('task'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TaskAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $task = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('activity_project::task.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(TaskAdminRequest $request, $id)
    {
        $task = $this->model->find($id);

        Former::populate($task);

        return view('activity_project::admin.task.edit', compact('task'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(TaskAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $task = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('activity_project::task.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(TaskAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('activity_project::task.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
