<?php

namespace Database\ActivityProject\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Database\ActivityProject\Http\Requests\TaskUserRequest;
use Database\ActivityProject\Interfaces\TaskRepositoryInterface;
use Response;
use User;

class TaskUserController extends UserController
{
    /**
     * Initialize task controller.
     *
     * @param type TaskRepositoryInterface $task
     *
     * @return type
     */
    public function __construct(TaskRepositoryInterface $task)
    {
        $this->model = $task;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(TaskUserRequest $request)
    {
        $tasks = $this->model->all();

        $this->theme->prependTitle(trans('activity_project::task.names').' :: ');

        return $this->theme->of('activity_project::user.task.index', compact('tasks'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(TaskUserRequest $request, $role, $id)
    {
        $task = $this->model->find($id);

        return $this->theme->of('activity_project::user.task.show', compact('task'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TaskUserRequest $request)
    {
        $task = $this->model->findOrNew(0);

        Former::populate($task);

        return $this->theme->of('activity_project::user.task.create', compact('task'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TaskUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $task = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('activity_project::task.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(TaskUserRequest $request, $role, $id)
    {
        $task = $this->model->find($id);

        Former::populate($task);

        return $this->theme->of('activity_project::user.task.edit', compact('task'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(TaskUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $task = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('activity_project::task.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(TaskUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('activity_project::task.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
