<?php

namespace Database\ActivityProject\Providers;

use Illuminate\Support\ServiceProvider;

class ActivityProjectServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__.'/../../../../resources/views', 'activity_project');

        // Load translation
        $this->loadTranslationsFrom(__DIR__.'/../../../../resources/lang', 'activity_project');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__.'/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('activity_project', function ($app) {
            return $this->app->make('Database\ActivityProject\ActivityProject');
        });

        // Repository binds
        // Bind ActivityProject to repository
        $this->app->bind(
            \Database\ActivityProject\Interfaces\ActivityProjectRepositoryInterface::class,
            \Database\ActivityProject\Repositories\Eloquent\ActivityProjectRepository::class
        );
        // Bind Task to repository
        $this->app->bind(
            \Database\ActivityProject\Interfaces\TaskRepositoryInterface::class,
            \Database\ActivityProject\Repositories\Eloquent\TaskRepository::class
        );
        // Bind AcitivityProject to repository
        $this->app->bind(
            \Database\ActivityProject\Interfaces\AcitivityProjectRepositoryInterface::class,
            \Database\ActivityProject\Repositories\Eloquent\AcitivityProjectRepository::class
        );
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['activity_project'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__.'/../../../../config/config.php' => config_path('package/activity_project.php')], 'config');

        // Publish public view
        $this->publishes([__DIR__.'/../../../../resources/views/public'  => base_path('resources/views/vendor/activity_project/public')], 'view-public');

        // Publish admin view
        $this->publishes([__DIR__.'/../../../../resources/views/admin' => base_path('resources/views/vendor/activity_project/admin')], 'view-admin');

        // Publish language files
        $this->publishes([__DIR__.'/../../../../resources/lang' => base_path('resources/lang/vendor/courier')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__.'/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__.'/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');
    }
}
